@@ -10,6 +10,9 @@ class BundleRecipient:
         'note': None,     # string - A note sent to the recipient with the bundle.
         'recipient': None,     # string - The recipient's email address.
         'sent_at': None,     # date-time - When the Bundle was shared with this recipient.
+        'user_id': None,     # int64 - User ID.  Provide a value of `0` to operate the current session's user.
+        'bundle_id': None,     # int64 - Bundle to share.
+        'share_after_create': None,     # boolean - Set to true to share the link with the recipient upon creation.
     }
 
     def __init__(self, attributes=None, options=None):
@@ -28,6 +31,13 @@ class BundleRecipient:
         return {k: getattr(self, k, None) for k in BundleRecipient.default_attributes if getattr(self, k, None) is not None}
 
 
+    def save(self):
+        if hasattr(self, "id") and self.id:
+            raise NotImplementedError("The BundleRecipient object doesn't support updates.")
+        else:
+            new_obj = create(self.get_attributes(), self.options)
+            self.set_attributes(new_obj.get_attributes())
+
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
 #   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
@@ -41,6 +51,10 @@ class BundleRecipient:
 #   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `has_registrations`.
 #   bundle_id (required) - int64 - List recipients for the bundle with this ID.
 def list(params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
     if "cursor" in params and not isinstance(params["cursor"], str):
@@ -70,5 +84,37 @@ def list(params = None, options = None):
 def all(params = None, options = None):
     list(params, options)
 
+# Parameters:
+#   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
+#   bundle_id (required) - int64 - Bundle to share.
+#   recipient (required) - string - Email addresses to share this bundle with.
+#   name - string - Name of recipient.
+#   company - string - Company of recipient.
+#   note - string - Note to include in email.
+#   share_after_create - boolean - Set to true to share the link with the recipient upon creation.
+def create(params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
+    if "user_id" in params and not isinstance(params["user_id"], int):
+        raise InvalidParameterError("Bad parameter: user_id must be an int")
+    if "bundle_id" in params and not isinstance(params["bundle_id"], int):
+        raise InvalidParameterError("Bad parameter: bundle_id must be an int")
+    if "recipient" in params and not isinstance(params["recipient"], str):
+        raise InvalidParameterError("Bad parameter: recipient must be an str")
+    if "name" in params and not isinstance(params["name"], str):
+        raise InvalidParameterError("Bad parameter: name must be an str")
+    if "company" in params and not isinstance(params["company"], str):
+        raise InvalidParameterError("Bad parameter: company must be an str")
+    if "note" in params and not isinstance(params["note"], str):
+        raise InvalidParameterError("Bad parameter: note must be an str")
+    if "bundle_id" not in params:
+        raise MissingParameterError("Parameter missing: bundle_id")
+    if "recipient" not in params:
+        raise MissingParameterError("Parameter missing: recipient")
+    response, options = Api.send_request("POST", "/bundle_recipients", params, options)
+    return BundleRecipient(response.data, options)
+
 def new(*args, **kwargs):
     return BundleRecipient(*args, **kwargs)
\ No newline at end of file
